Heiko
=====

Heiko is a frontend for [MaaS](https://github.com/k4cg/matomat-service)
and a client to be run in K4CG

It provides functionality to run an accounting system on terminal basis 
on really old hardware.

Install
=======

Heiko is a pypi package that you can install via pip

    pip install heiko

For install from local git repository via git

    pip install .

For development, we need some extra packages, maintined in the target
\"dev\"

    pip install .[dev]

Run
===

    heiko

Configure
=========

You may want to configure your instance properly. For this see `config.template.yaml`
and copy it to `config.yaml`

Development:
============

swagger-client
--------------

MaaS (Matomat as a Service) API definition

This Python package is automatically generated by the [Swagger
Codegen](https://github.com/swagger-api/swagger-codegen) project:

-   API version: 0.5.2
-   Package version: 1.0.0
-   Build package: io.swagger.codegen.languages.PythonClientCodegen

Requirements.
-------------

Python 3.4+